summaryrefslogtreecommitdiffstats
path: root/plugins/rssfeed/rss/document.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
commit1c1403293485f35fd53db45aaa77a01cdd9627e7 (patch)
tree38559cd68cd4f63023fb5f6375def9db3b8b491e /plugins/rssfeed/rss/document.h
parent894f94545727610df22c4f73911d62d58266f695 (diff)
downloadktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.tar.gz
ktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.zip
TQt4 port ktorrent
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktorrent@1238733 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'plugins/rssfeed/rss/document.h')
-rw-r--r--plugins/rssfeed/rss/document.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/plugins/rssfeed/rss/document.h b/plugins/rssfeed/rss/document.h
index 1ead634..c65c15e 100644
--- a/plugins/rssfeed/rss/document.h
+++ b/plugins/rssfeed/rss/document.h
@@ -14,8 +14,8 @@
#include "article.h"
#include "global.h"
-class QDateTime;
-class QDomDocument;
+class TQDateTime;
+class TQDomDocument;
namespace RSS
{
@@ -45,7 +45,7 @@ namespace RSS
/**
* Constructs a Document from a piece of XML markup.
*/
- Document(const QDomDocument &doc);
+ Document(const TQDomDocument &doc);
/**
* Assignment operator.
@@ -75,28 +75,28 @@ namespace RSS
/**
* Convenience method. Differs from version() only in how the result
* is returned.
* @return A QString representing the verbose version of the
* document.
* @see version()
*/
- QString verbVersion() const;
+ TQString verbVersion() const;
/**
* RSS 0.90 and upwards
* @return The title of the RSS document, or QString::null if no
* title was available. This is often the name of the news source
* from which the RSS document was retrieved.
*/
- QString title() const;
+ TQString title() const;
/**
* RSS 0.90 and upwards
* @return The description of the RSS document, or QString::null
* if no description was available. This is usually a short slogan
* or description of the news source from which the RSS document
* was retrieved.
*/
- QString description() const;
+ TQString description() const;
/**
* RSS 0.90 and upwards
@@ -158,28 +158,28 @@ namespace RSS
/**
* RSS 0.91 and upwards
* @return A copyright of the information contained in the RSS
- * document, or QString::null if no copyright is available.
+ * document, or TQString() if no copyright is available.
*/
- QString copyright() const;
+ TQString copyright() const;
/**
* RSS 0.91 and upwards
* @return The date when the RSS document was published.
*/
- const QDateTime &pubDate() const;
+ const TQDateTime &pubDate() const;
/**
* RSS 0.91 and upwards.
* @return The last time the channel was modified.
*/
- const QDateTime &lastBuildDate() const;
+ const TQDateTime &lastBuildDate() const;
/**
* RSS 0.91 and upwards
* @return A <a href="http://www.w3.org/PICS/#Specs">PICS</a>
* rating for this page.
*/
- QString rating() const;
+ TQString rating() const;
/**
* RSS 0.91 and upwards
@@ -197,16 +197,16 @@ namespace RSS
* bull@mancuso.com (Bull Mancuso).
* @see webMaster()
*/
- QString managingEditor() const;
+ TQString managingEditor() const;
/**
* RSS 0.91 and upwards
* @return The email address of the webmaster for the site, the
* person to contact if there are technical problems with the
* channel, or QString::null if this information isn't available.
* @see managingEditor()
*/
- QString webMaster() const;
+ TQString webMaster() const;
/**
* RSS 0.91 and upwards
@@ -75,28 +75,28 @@ namespace RSS
* Convenience method. Differs from version() only in how the result
* is returned.
- * @return A QString representing the verbose version of the
+ * @return A TQString representing the verbose version of the
* document.
* @see version()
@@ -75,28 +75,28 @@ namespace RSS
/**
* RSS 0.90 and upwards
- * @return The title of the RSS document, or QString::null if no
+ * @return The title of the RSS document, or TQString() if no
* title was available. This is often the name of the news source
* from which the RSS document was retrieved.
@@ -75,28 +75,28 @@ namespace RSS
/**
* RSS 0.90 and upwards
- * @return The description of the RSS document, or QString::null
+ * @return The description of the RSS document, or TQString()
* if no description was available. This is usually a short slogan
* or description of the news source from which the RSS document
@@ -197,16 +197,16 @@ namespace RSS
* @return The email address of the webmaster for the site, the
* person to contact if there are technical problems with the
- * channel, or QString::null if this information isn't available.
+ * channel, or TQString() if this information isn't available.
* @see managingEditor()
*/